@@ -64,7 +64,7 @@ class Auditor
      * @param PackageInterface[] $packages
      * @param self::FORMAT_* $format The format that will be used to output audit results.
      * @param bool $warningOnly If true, outputs a warning. If false, outputs an error.
-     * @param string[] $ignoreList List of advisory IDs, remote IDs or CVE IDs that reported but not listed as vulnerabilities.
+     * @param string[] $ignoreList List of advisory IDs, remote IDs, CVE IDs or package names that reported but not listed as vulnerabilities.
      * @param self::ABANDONED_* $abandoned
      * @param array<string> $ignoredSeverities List of ignored severity levels
      * @param string[]|array<string, string> $ignoreAbandoned List of abandoned package name that reported but not listed as vulnerabilities.
@@ -80,7 +80,7 @@ class Auditor
 
         // we need the CVE & remote IDs set to filter ignores correctly so if we have any matches using the optimized codepath above
         // and ignores are set then we need to query again the full data to make sure it can be filtered
-        if (count($allAdvisories) > 0 && $ignoreList !== [] && $format === self::FORMAT_SUMMARY) {
+        if ($format === self::FORMAT_SUMMARY && $this->needsCompleteAdvisoryLoad($allAdvisories, $ignoreList)) {
             $result = $repoSet->getMatchingSecurityAdvisories($packages, false, $ignoreUnreachable);
             $allAdvisories = $result['advisories'];
             $unreachableRepos = array_merge($unreachableRepos, $result['unreachableRepos']);
@@ -157,6 +157,35 @@ class Auditor
         return $auditBitmask;
     }
 
+    /**
+     * @param array<string, array<SecurityAdvisory|PartialSecurityAdvisory>> $advisories
+     * @param array<string, string>|array<string> $ignoreList
+     * @return bool
+     */
+    public function needsCompleteAdvisoryLoad(array $advisories, array $ignoreList): bool
+    {
+        if (\count($advisories) === 0) {
+            return false;
+        }
+
+        // no partial advisories present
+        if (array_all($advisories, static function (array $pkgAdvisories) {
+            return array_all($pkgAdvisories, static function ($advisory) { return $advisory instanceof SecurityAdvisory; });
+        })) {
+            return false;
+        }
+
+        if (\count($ignoreList) > 0 && !\array_is_list($ignoreList)) {
+            $ignoredIds = array_keys($ignoreList);
+        } else {
+            $ignoredIds = $ignoreList;
+        }
+
+        return array_any($ignoredIds, static function ($id) {
+            return !str_starts_with($id, 'PKSA-');
+        });
+    }
+
     /**
      * @param array<PackageInterface> $packages
      * @param string[]|array<string, string> $ignoreAbandoned
@@ -182,7 +211,7 @@ class Auditor
 
     /**
      * @phpstan-param array<string, array<PartialSecurityAdvisory|SecurityAdvisory>> $allAdvisories
-     * @param array<string>|array<string,string> $ignoreList List of advisory IDs, remote IDs or CVE IDs that reported but not listed as vulnerabilities.
+     * @param array<string>|array<string,string> $ignoreList List of advisory IDs, remote IDs, CVE IDs or package names that reported but not listed as vulnerabilities.
      * @param array<string> $ignoredSeverities List of ignored severity levels
      * @phpstan-return array{advisories: array<string, array<PartialSecurityAdvisory|SecurityAdvisory>>, ignoredAdvisories: array<string, array<PartialSecurityAdvisory|SecurityAdvisory>>}
      */
@@ -206,6 +235,11 @@ class Auditor
             foreach ($pkgAdvisories as $advisory) {
                 $isActive = true;
 
+                if (in_array($package, $ignoredIds, true)) {
+                    $isActive = false;
+                    $ignoreReason = $ignoreList[$package] ?? null;
+                }
+
                 if (in_array($advisory->advisoryId, $ignoredIds, true)) {
                     $isActive = false;
                     $ignoreReason = $ignoreList[$advisory->advisoryId] ?? null;
@@ -299,6 +333,7 @@ class Auditor
                 $headers = [
                     'Package',
                     'Severity',
+                    'Advisory ID',
                     'CVE',
                     'Title',
                     'URL',
@@ -308,16 +343,13 @@ class Auditor
                 $row = [
                     $advisory->packageName,
                     $this->getSeverity($advisory),
+                    $this->getAdvisoryId($advisory),
                     $this->getCVE($advisory),
                     $advisory->title,
                     $this->getURL($advisory),
                     $advisory->affectedVersions->getPrettyString(),
                     $advisory->reportedAt->format(DATE_ATOM),
                 ];
-                if ($advisory->cve === null) {
-                    $headers[] = 'Advisory ID';
-                    $row[] = $advisory->advisoryId;
-                }
                 if ($advisory instanceof IgnoredSecurityAdvisory) {
                     $headers[] = 'Ignore reason';
                     $row[] = $advisory->ignoreReason ?? 'None specified';
@@ -347,10 +379,8 @@ class Auditor
                 }
                 $error[] = "Package: ".$advisory->packageName;
                 $error[] = "Severity: ".$this->getSeverity($advisory);
+                $error[] = "Advisory ID: ".$this->getAdvisoryId($advisory);
                 $error[] = "CVE: ".$this->getCVE($advisory);
-                if ($advisory->cve === null) {
-                    $error[] = "Advisory ID: ".$advisory->advisoryId;
-                }
                 $error[] = "Title: ".OutputFormatter::escape($advisory->title);
                 $error[] = "URL: ".$this->getURL($advisory);
                 $error[] = "Affected versions: ".OutputFormatter::escape($advisory->affectedVersions->getPrettyString());
@@ -420,6 +450,15 @@ class Auditor
         return $advisory->severity;
     }
 
+    private function getAdvisoryId(SecurityAdvisory $advisory): string
+    {
+        if (str_starts_with($advisory->advisoryId, 'PKSA-')) {
+            return '<href=https://packagist.org/security-advisories/'.$advisory->advisoryId.'>'.$advisory->advisoryId.'</>';
+        }
+
+        return $advisory->advisoryId;
+    }
+
     private function getCVE(SecurityAdvisory $advisory): string
     {
         if ($advisory->cve === null) {
