@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -27,9 +27,8 @@ class RuleWatchChain extends \SplDoublyLinkedList
      * Moves the internal iterator to the specified offset
      *
      * @param int $offset The offset to seek to.
-     * @return void
      */
-    public function seek($offset)
+    public function seek(int $offset): void
     {
         $this->rewind();
         for ($i = 0; $i < $offset; $i++, $this->next());
@@ -42,10 +41,8 @@ class RuleWatchChain extends \SplDoublyLinkedList
      * incorrectly sets the internal iterator if you delete the current value
      * this method sets the internal iterator back to the following element
      * using the seek method.
-     *
-     * @return void
      */
-    public function remove()
+    public function remove(): void
     {
         $offset = $this->key();
         $this->offsetUnset($offset);
