@@ -13,6 +13,7 @@
 namespace Composer\DependencyResolver;
 
 use Composer\Package\AliasPackage;
+use Composer\Package\CompletePackageInterface;
 use Composer\Package\Link;
 use Composer\Package\PackageInterface;
 use Composer\Repository\PlatformRepository;
@@ -76,6 +77,7 @@ class Transaction
                 if ($a instanceof AliasPackage !== $b instanceof AliasPackage) {
                     return $a instanceof AliasPackage ? -1 : 1;
                 }
+
                 // if names are the same, compare version, e.g. to sort aliases reliably, actual order does not matter
                 return strcmp($b->getVersion(), $a->getVersion());
             }
@@ -163,7 +165,15 @@ class Transaction
                         // TODO different for lock?
                         if ($package->getVersion() !== $presentPackageMap[$package->getName()]->getVersion() ||
                             $package->getDistReference() !== $presentPackageMap[$package->getName()]->getDistReference() ||
-                            $package->getSourceReference() !== $presentPackageMap[$package->getName()]->getSourceReference()
+                            $package->getSourceReference() !== $presentPackageMap[$package->getName()]->getSourceReference() ||
+                            (
+                                $package instanceof CompletePackageInterface
+                                && $presentPackageMap[$package->getName()] instanceof CompletePackageInterface
+                                && (
+                                    $package->isAbandoned() !== $presentPackageMap[$package->getName()]->isAbandoned()
+                                    || $package->getReplacementPackage() !== $presentPackageMap[$package->getName()]->getReplacementPackage()
+                                )
+                            )
                         ) {
                             $operations[] = new Operation\UpdateOperation($source, $package);
                         }
