@@ -14,10 +14,10 @@ namespace Composer\EventDispatcher;
 
 use Composer\DependencyResolver\Transaction;
 use Composer\Installer\InstallerEvent;
-use Composer\IO\BufferIO;
 use Composer\IO\ConsoleIO;
 use Composer\IO\IOInterface;
 use Composer\Composer;
+use Composer\Package\PackageInterface;
 use Composer\PartialComposer;
 use Composer\Pcre\Preg;
 use Composer\Plugin\CommandEvent;
@@ -69,13 +69,16 @@ class EventDispatcher
     private $eventStack;
     /** @var list<string> */
     private $skipScripts;
+    /** @var string|null */
+    private $previousHash = null;
+    /** @var array<string, true> */
+    private $previousListeners = [];
 
     /**
      * Constructor.
      *
      * @param PartialComposer $composer The composer instance
      * @param IOInterface     $io       The IOInterface instance
-     * @param ProcessExecutor $process
      */
     public function __construct(PartialComposer $composer, IOInterface $io, ?ProcessExecutor $process = null)
     {
@@ -85,7 +88,7 @@ class EventDispatcher
         $this->eventStack = [];
         $this->skipScripts = array_values(array_filter(
             array_map('trim', explode(',', (string) Platform::getEnv('COMPOSER_SKIP_SCRIPTS'))),
-            function ($val) {
+            static function ($val) {
                 return $val !== '';
             }
         ));
@@ -136,7 +139,7 @@ class EventDispatcher
     {
         assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
 
-        return $this->doDispatch(new Script\Event($eventName, $this->composer, $this->io, $devMode, $additionalArgs, $flags));
+        return $this->doDispatch(new ScriptEvent($eventName, $this->composer, $this->io, $devMode, $additionalArgs, $flags));
     }
 
     /**
@@ -217,6 +220,7 @@ class EventDispatcher
                 }
                 $formattedEventNameWithArgs = $event->getName() . ($additionalArgs !== [] ? ' (' . implode(', ', $additionalArgs) . ')' : '');
                 if (!is_string($callable)) {
+                    $this->makeAutoloader($event, $callable);
                     if (!is_callable($callable)) {
                         $className = is_object($callable[0]) ? get_class($callable[0]) : $callable[0];
 
@@ -259,7 +263,7 @@ class EventDispatcher
 
                         try {
                             /** @var InstallerEvent $event */
-                            $scriptEvent = new Script\Event($scriptName, $event->getComposer(), $event->getIO(), $event->isDevMode(), $args, $flags);
+                            $scriptEvent = new ScriptEvent($scriptName, $event->getComposer(), $event->getIO(), $event->isDevMode(), $args, $flags);
                             $scriptEvent->setOriginatingEvent($event);
                             $return = $this->dispatch($scriptName, $scriptEvent);
                         } catch (ScriptExecutionException $e) {
@@ -271,6 +275,7 @@ class EventDispatcher
                     $className = substr($callable, 0, strpos($callable, '::'));
                     $methodName = substr($callable, strpos($callable, '::') + 2);
 
+                    $this->makeAutoloader($event, $callable);
                     if (!class_exists($className)) {
                         $this->io->writeError('<warning>Class '.$className.' is not autoloadable, can not call '.$event->getName().' script</warning>', true, IOInterface::QUIET);
                         continue;
@@ -289,6 +294,8 @@ class EventDispatcher
                     }
                 } elseif ($this->isCommandClass($callable)) {
                     $className = $callable;
+
+                    $this->makeAutoloader($event, [$callable, 'run']);
                     if (!class_exists($className)) {
                         $this->io->writeError('<warning>Class '.$className.' is not autoloadable, can not call '.$event->getName().' script</warning>', true, IOInterface::QUIET);
                         continue;
@@ -607,23 +614,6 @@ class EventDispatcher
             return [];
         }
 
-        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
-
-        if ($this->loader) {
-            $this->loader->unregister();
-        }
-
-        $generator = $this->composer->getAutoloadGenerator();
-        if ($event instanceof ScriptEvent) {
-            $generator->setDevMode($event->isDevMode());
-        }
-
-        $packages = $this->composer->getRepositoryManager()->getLocalRepository()->getCanonicalPackages();
-        $packageMap = $generator->buildPackageMap($this->composer->getInstallationManager(), $package, $packages);
-        $map = $generator->parseAutoloads($packageMap, $package);
-        $this->loader = $generator->createLoader($map, $this->composer->getConfig()->get('vendor-dir'));
-        $this->loader->register(false);
-
         return $scripts[$event->getName()];
     }
 
@@ -648,7 +638,7 @@ class EventDispatcher
      */
     protected function isComposerScript(string $callable): bool
     {
-        return strpos($callable, '@') === 0 && strpos($callable, '@php ') !== 0 && strpos($callable, '@putenv ') !== 0;
+        return str_starts_with($callable, '@') && !str_starts_with($callable, '@php ') && !str_starts_with($callable, '@putenv ');
     }
 
     /**
@@ -714,4 +704,58 @@ class EventDispatcher
         // not great but also do not want to break everything here
         return 'unsupported';
     }
+
+    /**
+     * @param mixed $callable Technically a callable shape but as the class may not be autoloadable yet PHP might not see it this way, so we cannot type hint as such
+     */
+    private function makeAutoloader(Event $event, $callable): void
+    {
+        assert($this->composer instanceof Composer, new \LogicException('This should only be reached with a fully loaded Composer'));
+
+        if (is_array($callable)) {
+            if (is_string($callable[0])) {
+                $callableKey = $callable[0] . '::' . $callable[1];
+            } else {
+                $callableKey = get_class($callable[0]).'::'.$callable[1];
+            }
+        } elseif (is_string($callable)) {
+            $callableKey = $callable;
+        } elseif ($callable instanceof \Closure) {
+            $callableKey = 'closure';
+        } else {
+            $callableKey = 'unknown';
+        }
+        if (isset($this->previousListeners[$callableKey])) {
+            return;
+        }
+        $this->previousListeners[$callableKey] = true;
+
+        $package = $this->composer->getPackage();
+        $packages = $this->composer->getRepositoryManager()->getLocalRepository()->getCanonicalPackages();
+        $generator = $this->composer->getAutoloadGenerator();
+        $hash = implode(',', array_map(static function (PackageInterface $p) {
+            return $p->getName().'/'.$p->getVersion();
+        }, $packages));
+        if ($event instanceof ScriptEvent || $event instanceof PackageEvent || $event instanceof InstallerEvent) {
+            $generator->setDevMode($event->isDevMode());
+            $hash .= $event->isDevMode() ? '/dev' : '';
+        }
+        $hash = hash('sha256', $hash);
+
+        if ($this->previousHash === $hash) {
+            return;
+        }
+
+        $this->previousHash = $hash;
+
+        $packageMap = $generator->buildPackageMap($this->composer->getInstallationManager(), $package, $packages);
+        $map = $generator->parseAutoloads($packageMap, $package);
+
+        if ($this->loader !== null) {
+            $this->loader->unregister();
+        }
+
+        $this->loader = $generator->createLoader($map, $this->composer->getConfig()->get('vendor-dir'));
+        $this->loader->register(false);
+    }
 }
