@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -25,10 +25,9 @@ class JsonValidationException extends Exception
     protected $errors;
 
     /**
-     * @param string   $message
      * @param string[] $errors
      */
-    public function __construct($message, $errors = array(), Exception $previous = null)
+    public function __construct(string $message, array $errors = [], ?Exception $previous = null)
     {
         $this->errors = $errors;
         parent::__construct((string) $message, 0, $previous);
@@ -37,7 +36,7 @@ class JsonValidationException extends Exception
     /**
      * @return string[]
      */
-    public function getErrors()
+    public function getErrors(): array
     {
         return $this->errors;
     }
