@@ -66,13 +66,21 @@ class Locker
     {
         $this->lockFile = $lockFile;
         $this->installationManager = $installationManager;
-        $this->hash = md5($composerFileContents);
+        $this->hash = hash('md5', $composerFileContents);
         $this->contentHash = self::getContentHash($composerFileContents);
         $this->loader = new ArrayLoader(null, true);
         $this->dumper = new ArrayDumper();
         $this->process = $process ?? new ProcessExecutor($io);
     }
 
+    /**
+     * @internal
+     */
+    public function getJsonFile(): JsonFile
+    {
+        return $this->lockFile;
+    }
+
     /**
      * Returns the md5 hash of the sorted content of the composer file.
      *
@@ -107,7 +115,7 @@ class Locker
 
         ksort($relevantContent);
 
-        return md5(JsonFile::encode($relevantContent, 0));
+        return hash('md5', JsonFile::encode($relevantContent, 0));
     }
 
     /**
@@ -217,7 +225,7 @@ class Locker
      * Returns the platform requirements stored in the lock file
      *
      * @param  bool                     $withDevReqs if true, the platform requirements from the require-dev block are also returned
-     * @return \Composer\Package\Link[]
+     * @return Link[]
      */
     public function getPlatformRequirements(bool $withDevReqs = false): array
     {
@@ -247,6 +255,9 @@ class Locker
         return $requirements;
     }
 
+    /**
+     * @return key-of<BasePackage::STABILITIES>
+     */
     public function getMinimumStability(): string
     {
         $lockData = $this->getLockData();
@@ -361,7 +372,7 @@ class Locker
                                'Read more about it at https://getcomposer.org/doc/01-basic-usage.md#installing-dependencies',
                                'This file is @gener'.'ated automatically', ],
             'content-hash' => $this->contentHash,
-            'packages' => null,
+            'packages' => $this->lockPackages($packages),
             'packages-dev' => null,
             'aliases' => $aliases,
             'minimum-stability' => $minimumStability,
@@ -370,7 +381,6 @@ class Locker
             'prefer-lowest' => $preferLowest,
         ];
 
-        $lock['packages'] = $this->lockPackages($packages);
         if (null !== $devPackages) {
             $lock['packages-dev'] = $this->lockPackages($devPackages);
         }
@@ -382,6 +392,8 @@ class Locker
         }
         $lock['plugin-api-version'] = PluginInterface::PLUGIN_API_VERSION;
 
+        $lock = $this->fixupJsonDataType($lock);
+
         try {
             $isLocked = $this->isLocked();
         } catch (ParsingException $e) {
@@ -403,6 +415,60 @@ class Locker
         return false;
     }
 
+    /**
+     * Updates the lock file's hash in-place from a given composer.json's JsonFile
+     *
+     * This does not reload or require any packages, and retains the filemtime of the lock file.
+     *
+     * Use this only to update the lock file hash after updating a composer.json in ways that are guaranteed NOT to impact the dependency resolution.
+     *
+     * This is a risky method, use carefully.
+     *
+     * @param (callable(array<string, mixed>): array<string, mixed>)|null $dataProcessor Receives the lock data and can process it before it gets written to disk
+     */
+    public function updateHash(JsonFile $composerJson, ?callable $dataProcessor = null): void
+    {
+        $contents = file_get_contents($composerJson->getPath());
+        if (false === $contents) {
+            throw new \RuntimeException('Unable to read '.$composerJson->getPath().' contents to update the lock file hash.');
+        }
+
+        $lockMtime = filemtime($this->lockFile->getPath());
+        $lockData = $this->lockFile->read();
+        $lockData['content-hash'] = Locker::getContentHash($contents);
+        if ($dataProcessor !== null) {
+            $lockData = $dataProcessor($lockData);
+        }
+
+        $this->lockFile->write($this->fixupJsonDataType($lockData));
+        $this->lockDataCache = null;
+        $this->virtualFileWritten = false;
+        if (is_int($lockMtime)) {
+            @touch($this->lockFile->getPath(), $lockMtime);
+        }
+    }
+
+    /**
+     * Ensures correct data types and ordering for the JSON lock format
+     *
+     * @param array<mixed> $lockData
+     * @return array<mixed>
+     */
+    private function fixupJsonDataType(array $lockData): array
+    {
+        foreach (['stability-flags', 'platform', 'platform-dev'] as $key) {
+            if (isset($lockData[$key]) && is_array($lockData[$key]) && \count($lockData[$key]) === 0) {
+                $lockData[$key] = new \stdClass();
+            }
+        }
+
+        if (is_array($lockData['stability-flags'])) {
+            ksort($lockData['stability-flags']);
+        }
+
+        return $lockData;
+    }
+
     /**
      * @param PackageInterface[] $packages
      *
@@ -488,13 +554,14 @@ class Locker
                 case 'git':
                     GitUtil::cleanEnv();
 
-                    if (0 === $this->process->execute('git log -n1 --pretty=%ct '.ProcessExecutor::escape($sourceRef).GitUtil::getNoShowSignatureFlag($this->process), $output, $path) && Preg::isMatch('{^\s*\d+\s*$}', $output)) {
+                    $command = array_merge(['git', 'log', '-n1', '--pretty=%ct', (string) $sourceRef], GitUtil::getNoShowSignatureFlags($this->process));
+                    if (0 === $this->process->execute($command, $output, $path) && Preg::isMatch('{^\s*\d+\s*$}', $output)) {
                         $datetime = new \DateTime('@'.trim($output), new \DateTimeZone('UTC'));
                     }
                     break;
 
                 case 'hg':
-                    if (0 === $this->process->execute('hg log --template "{date|hgdate}" -r '.ProcessExecutor::escape($sourceRef), $output, $path) && Preg::isMatch('{^\s*(\d+)\s*}', $output, $match)) {
+                    if (0 === $this->process->execute(['hg', 'log', '--template', '{date|hgdate}', '-r', (string) $sourceRef], $output, $path) && Preg::isMatch('{^\s*(\d+)\s*}', $output, $match)) {
                         $datetime = new \DateTime('@'.$match[1], new \DateTimeZone('UTC'));
                     }
                     break;
