@@ -14,7 +14,6 @@ namespace Composer\Util\Http;
 
 use Composer\Json\JsonFile;
 use Composer\Pcre\Preg;
-use Composer\Util\HttpDownloader;
 
 /**
  * @phpstan-type Request array{url: non-empty-string, options?: mixed[], copyTo?: string|null}
@@ -72,17 +71,11 @@ class Response
         return $this->headers;
     }
 
-    /**
-     * @return ?string
-     */
     public function getHeader(string $name): ?string
     {
         return self::findHeaderValue($this->headers, $name);
     }
 
-    /**
-     * @return ?string
-     */
     public function getBody(): ?string
     {
         return $this->body;
