@@ -13,6 +13,7 @@
 namespace Composer\Util;
 
 use Composer\Downloader\DownloaderInterface;
+use Composer\Downloader\DownloadManager;
 use Composer\Package\PackageInterface;
 use React\Promise\PromiseInterface;
 
@@ -23,22 +24,24 @@ class SyncHelper
      *
      * This executes all the required steps and waits for promises to complete
      *
-     * @param Loop                  $loop        Loop instance which you can get from $composer->getLoop()
-     * @param DownloaderInterface   $downloader  Downloader instance you can get from $composer->getDownloadManager()->getDownloader('zip') for example
-     * @param string                $path        the installation path for the package
-     * @param PackageInterface      $package     the package to install
-     * @param PackageInterface|null $prevPackage the previous package if this is an update and not an initial installation
+     * @param Loop                                $loop        Loop instance which you can get from $composer->getLoop()
+     * @param DownloaderInterface|DownloadManager $downloader  DownloadManager instance or Downloader instance you can get from $composer->getDownloadManager()->getDownloader('zip') for example
+     * @param string                              $path        The installation path for the package
+     * @param PackageInterface                    $package     The package to install
+     * @param PackageInterface|null               $prevPackage The previous package if this is an update and not an initial installation
      */
-    public static function downloadAndInstallPackageSync(Loop $loop, DownloaderInterface $downloader, string $path, PackageInterface $package, ?PackageInterface $prevPackage = null): void
+    public static function downloadAndInstallPackageSync(Loop $loop, $downloader, string $path, PackageInterface $package, ?PackageInterface $prevPackage = null): void
     {
-        $type = $prevPackage ? 'update' : 'install';
+        assert($downloader instanceof DownloaderInterface || $downloader instanceof DownloadManager);
+
+        $type = $prevPackage !== null ? 'update' : 'install';
 
         try {
             self::await($loop, $downloader->download($package, $path, $prevPackage));
 
             self::await($loop, $downloader->prepare($type, $package, $path, $prevPackage));
 
-            if ($type === 'update') {
+            if ($type === 'update' && $prevPackage !== null) {
                 self::await($loop, $downloader->update($package, $prevPackage, $path));
             } else {
                 self::await($loop, $downloader->install($package, $path));
@@ -55,10 +58,11 @@ class SyncHelper
      * Waits for a promise to resolve
      *
      * @param Loop                  $loop    Loop instance which you can get from $composer->getLoop()
+     * @phpstan-param PromiseInterface<mixed>|null $promise
      */
     public static function await(Loop $loop, ?PromiseInterface $promise = null): void
     {
-        if ($promise) {
+        if ($promise !== null) {
             $loop->wait([$promise]);
         }
     }
