@@ -20,8 +20,10 @@ use Composer\Package\Package;
 use Composer\Package\Version\VersionParser;
 use Composer\Repository\ComposerRepository;
 use Composer\Repository\RepositorySet;
+use Composer\Semver\Constraint\Constraint;
 use Composer\Test\TestCase;
 use Composer\Advisory\Auditor;
+use DateTimeImmutable;
 use InvalidArgumentException;
 
 class AuditorTest extends TestCase
@@ -54,6 +56,7 @@ class AuditorTest extends TestCase
             'output' => '<warning>Found 2 security vulnerability advisories affecting 1 package:</warning>
 Package: vendor1/package1
 Severity: high
+Advisory ID: ID4
 CVE: CVE3
 Title: advisory4
 URL: https://advisory.example.com/advisory4
@@ -62,6 +65,7 @@ Reported at: 2022-05-25T13:21:00+00:00
 --------
 Package: vendor1/package1
 Severity: medium
+Advisory ID: ID5
 CVE: '.'
 Title: advisory5
 URL: https://advisory.example.com/advisory5
@@ -87,6 +91,51 @@ Reported at: 2022-05-25T13:21:00+00:00',
             'output' => 'No security vulnerability advisories found.',
         ];
 
+        yield 'abandoned packages individually ignored via full vendor' => [
+            'data' => [
+                'packages' => [
+                    $abandonedWithReplacement,
+                    $abandonedNoReplacement,
+                ],
+                'warningOnly' => false,
+                'abandoned' => Auditor::ABANDONED_FAIL,
+                'ignore-abandoned' => ['vendor/*'],
+            ],
+            'expected' => Auditor::STATUS_OK,
+            'output' => 'No security vulnerability advisories found.',
+        ];
+
+        yield 'abandoned packages individually ignored via package name' => [
+            'data' => [
+                'packages' => [
+                    $abandonedWithReplacement,
+                    $abandonedNoReplacement,
+                ],
+                'warningOnly' => false,
+                'abandoned' => Auditor::ABANDONED_FAIL,
+                'ignore-abandoned' => [$abandonedWithReplacement->getName(), $abandonedNoReplacement->getName()],
+            ],
+            'expected' => Auditor::STATUS_OK,
+            'output' => 'No security vulnerability advisories found.',
+        ];
+
+        yield 'abandoned packages individually ignored not matching package name' => [
+            'data' => [
+                'packages' => [
+                    $abandonedWithReplacement,
+                    $abandonedNoReplacement,
+                ],
+                'warningOnly' => false,
+                'abandoned' => Auditor::ABANDONED_FAIL,
+                'ignore-abandoned' => ['acme/test'],
+            ],
+            'expected' => Auditor::STATUS_ABANDONED,
+            'output' => 'No security vulnerability advisories found.
+Found 2 abandoned packages:
+vendor/abandoned is abandoned. Use foo/bar instead.
+vendor/abandoned2 is abandoned. No replacement was suggested.',
+        ];
+
         yield 'abandoned packages reported only' => [
             'data' => [
                 'packages' => [
@@ -140,6 +189,7 @@ Found 2 abandoned packages:
 +-------------------+----------------------------------------------------------------------------------+
 | Package           | vendor1/package1                                                                 |
 | Severity          | high                                                                             |
+| Advisory ID       | ID4                                                                              |
 | CVE               | CVE3                                                                             |
 | Title             | advisory4                                                                        |
 | URL               | https://advisory.example.com/advisory4                                           |
@@ -149,6 +199,7 @@ Found 2 abandoned packages:
 +-------------------+----------------------------------------------------------------------------------+
 | Package           | vendor1/package1                                                                 |
 | Severity          | medium                                                                           |
+| Advisory ID       | ID5                                                                              |
 | CVE               |                                                                                  |
 | Title             | advisory5                                                                        |
 | URL               | https://advisory.example.com/advisory5                                           |
@@ -195,7 +246,7 @@ Found 2 abandoned packages:
             $this->expectException(InvalidArgumentException::class);
         }
         $auditor = new Auditor();
-        $result = $auditor->audit($io = new BufferIO(), $this->getRepoSet(), $data['packages'], $data['format'] ?? Auditor::FORMAT_PLAIN, $data['warningOnly'], [], $data['abandoned'] ?? Auditor::ABANDONED_IGNORE);
+        $result = $auditor->audit($io = new BufferIO(), $this->getRepoSet(), $data['packages'], $data['format'] ?? Auditor::FORMAT_PLAIN, $data['warningOnly'], [], $data['abandoned'] ?? Auditor::ABANDONED_IGNORE, [], false, $data['ignore-abandoned'] ?? []);
         self::assertSame($expected, $result);
         self::assertSame($output, trim(str_replace("\r", '', $io->getOutput())));
     }
@@ -212,6 +263,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendor1/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID1'],
                 ['text' => 'CVE: CVE1'],
                 ['text' => 'Title: advisory1'],
                 ['text' => 'URL: https://advisory.example.com/advisory1'],
@@ -229,6 +281,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendor1/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID1'],
                 ['text' => 'CVE: CVE1'],
                 ['text' => 'Title: advisory1'],
                 ['text' => 'URL: https://advisory.example.com/advisory1'],
@@ -247,6 +300,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendor1/package2'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID2'],
                 ['text' => 'CVE: '],
                 ['text' => 'Title: advisory2'],
                 ['text' => 'URL: https://advisory.example.com/advisory2'],
@@ -264,6 +318,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendorx/packagex'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: IDx'],
                 ['text' => 'CVE: CVE5'],
                 ['text' => 'Title: advisory17'],
                 ['text' => 'URL: https://advisory.example.com/advisory17'],
@@ -271,6 +326,43 @@ Found 2 abandoned packages:
                 ['text' => 'Reported at: 2015-05-25T13:21:00+00:00'],
             ],
         ];
+        yield 'ignore by package name' => [
+            [
+                new Package('vendor1/package1', '3.0.0.0', '3.0.0'),
+            ],
+            ['vendor1/package1'],
+            0,
+            [
+                ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
+                ['text' => 'Package: vendor1/package1'],
+                ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID1'],
+                ['text' => 'CVE: CVE1'],
+                ['text' => 'Title: advisory1'],
+                ['text' => 'URL: https://advisory.example.com/advisory1'],
+                ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
+                ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
+            ],
+        ];
+        yield 'ignore by package name with reasoning' => [
+            [
+                new Package('vendor1/package1', '3.0.0.0', '3.0.0'),
+            ],
+            ['vendor1/package1' => 'Package has known safe usage'],
+            0,
+            [
+                ['text' => 'Found 1 ignored security vulnerability advisory affecting 1 package:'],
+                ['text' => 'Package: vendor1/package1'],
+                ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID1'],
+                ['text' => 'CVE: CVE1'],
+                ['text' => 'Title: advisory1'],
+                ['text' => 'URL: https://advisory.example.com/advisory1'],
+                ['text' => 'Affected versions: >=3,<3.4.3|>=1,<2.5.6'],
+                ['text' => 'Reported at: 2022-05-25T13:21:00+00:00'],
+                ['text' => 'Ignore reason: Package has known safe usage'],
+            ],
+        ];
         yield '1 vulnerability, 0 ignored' => [
             [
                 new Package('vendor1/package1', '3.0.0.0', '3.0.0'),
@@ -281,6 +373,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendor1/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID1'],
                 ['text' => 'CVE: CVE1'],
                 ['text' => 'Title: advisory1'],
                 ['text' => 'URL: https://advisory.example.com/advisory1'],
@@ -302,6 +395,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 3 ignored security vulnerability advisories affecting 2 packages:'],
                 ['text' => 'Package: vendor2/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID3'],
                 ['text' => 'CVE: CVE2'],
                 ['text' => 'Title: advisory3'],
                 ['text' => 'URL: https://advisory.example.com/advisory3'],
@@ -311,6 +405,7 @@ Found 2 abandoned packages:
                 ['text' => '--------'],
                 ['text' => 'Package: vendor2/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID6'],
                 ['text' => 'CVE: CVE4'],
                 ['text' => 'Title: advisory6'],
                 ['text' => 'URL: https://advisory.example.com/advisory6'],
@@ -320,6 +415,7 @@ Found 2 abandoned packages:
                 ['text' => '--------'],
                 ['text' => 'Package: vendorx/packagex'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: IDx'],
                 ['text' => 'CVE: CVE5'],
                 ['text' => 'Title: advisory17'],
                 ['text' => 'URL: https://advisory.example.com/advisory17'],
@@ -329,6 +425,7 @@ Found 2 abandoned packages:
                 ['text' => 'Found 1 security vulnerability advisory affecting 1 package:'],
                 ['text' => 'Package: vendor3/package1'],
                 ['text' => 'Severity: medium'],
+                ['text' => 'Advisory ID: ID7'],
                 ['text' => 'CVE: CVE5'],
                 ['text' => 'Title: advisory7'],
                 ['text' => 'URL: https://advisory.example.com/advisory7'],
@@ -340,7 +437,7 @@ Found 2 abandoned packages:
 
     /**
      * @dataProvider ignoredIdsProvider
-     * @phpstan-param array<\Composer\Package\Package> $packages
+     * @phpstan-param array<Package> $packages
      * @phpstan-param array<string>|array<string,string> $ignoredIds
      * @phpstan-param 0|positive-int $exitCode
      * @phpstan-param list<array{text: string, verbosity?: \Composer\IO\IOInterface::*, regex?: true}|array{ask: string, reply: string}|array{auth: array{string, string, string|null}}> $expectedOutput
@@ -387,9 +484,113 @@ Found 2 abandoned packages:
         ];
     }
 
+    public function testAuditWithIgnoreUnreachable(): void
+    {
+        $packages = [
+            new Package('vendor1/package1', '3.0.0.0', '3.0.0'),
+        ];
+
+        $errorMessage = 'The "https://example.org/packages.json" file could not be downloaded: HTTP/1.1 404 Not Found';
+
+        // Create a mock RepositorySet that simulates multiple repositories with the middle one being unreachable
+        $repoSet = $this->getMockBuilder(RepositorySet::class)
+            ->disableOriginalConstructor()
+            ->onlyMethods(['getMatchingSecurityAdvisories'])
+            ->getMock();
+
+        $repoSet->method('getMatchingSecurityAdvisories')
+            ->willReturnCallback(static function ($packages, $allowPartialAdvisories, $ignoreUnreachable) use ($errorMessage) {
+                if (!$ignoreUnreachable) {
+                    throw new \Composer\Downloader\TransportException($errorMessage, 404);
+                }
+
+                // Simulate multiple repositories with the middle one being unreachable
+                // First and third repositories have advisories, middle one is unreachable
+                return [
+                    'advisories' => [
+                        'vendor1/package1' => [
+                            new SecurityAdvisory(
+                                'vendor1/package1',
+                                'CVE-2023-12345',
+                                new \Composer\Semver\Constraint\Constraint('=', '3.0.0.0'),
+                                'First repo advisory',
+                                [['name' => 'test', 'remoteId' => '1']],
+                                new \DateTimeImmutable('2023-01-01', new \DateTimeZone('UTC')),
+                                'CVE-2023-12345',
+                                'https://example.com/advisory/1',
+                                'medium'
+                            ),
+                            new SecurityAdvisory(
+                                'vendor1/package1',
+                                'CVE-2023-67890',
+                                new \Composer\Semver\Constraint\Constraint('=', '3.0.0.0'),
+                                'Third repo advisory',
+                                [['name' => 'test', 'remoteId' => '3']],
+                                new \DateTimeImmutable('2023-01-01', new \DateTimeZone('UTC')),
+                                'CVE-2023-67890',
+                                'https://example.com/advisory/3',
+                                'high'
+                            ),
+                        ],
+                    ],
+                    'unreachableRepos' => [$errorMessage],
+                ];
+            });
+
+        $auditor = new Auditor();
+
+        // Test without ignoreUnreachable flag
+        try {
+            $auditor->audit(new BufferIO(), $repoSet, $packages, Auditor::FORMAT_PLAIN, false);
+            self::fail('Expected TransportException was not thrown');
+        } catch (\Composer\Downloader\TransportException $e) {
+            self::assertStringContainsString('HTTP/1.1 404 Not Found', $e->getMessage());
+        }
+
+        // Test with ignoreUnreachable flag
+        $io = new BufferIO();
+        $result = $auditor->audit($io, $repoSet, $packages, Auditor::FORMAT_PLAIN, false, [], Auditor::ABANDONED_IGNORE, [], true);
+
+        // Should find advisories from the reachable repositories
+        self::assertSame(Auditor::STATUS_VULNERABLE, $result);
+
+        $output = $io->getOutput();
+        self::assertStringContainsString('The following repositories were unreachable:', $output);
+        self::assertStringContainsString('HTTP/1.1 404 Not Found', $output);
+
+        // Verify that advisories from reachable repositories were found
+        self::assertStringContainsString('First repo advisory', $output);
+        self::assertStringContainsString('Third repo advisory', $output);
+        self::assertStringContainsString('CVE-2023-12345', $output);
+        self::assertStringContainsString('CVE-2023-67890', $output);
+
+        // Test with JSON format
+        $io = new BufferIO();
+        $result = $auditor->audit($io, $repoSet, $packages, Auditor::FORMAT_JSON, false, [], Auditor::ABANDONED_IGNORE, [], true);
+        self::assertSame(Auditor::STATUS_VULNERABLE, $result);
+
+        $json = json_decode($io->getOutput(), true);
+        self::assertArrayHasKey('unreachable-repositories', $json);
+        self::assertCount(1, $json['unreachable-repositories']);
+        self::assertStringContainsString('HTTP/1.1 404 Not Found', $json['unreachable-repositories'][0]);
+
+        // Verify that advisories from reachable repositories were included in JSON output
+        self::assertArrayHasKey('advisories', $json);
+        self::assertArrayHasKey('vendor1/package1', $json['advisories']);
+        self::assertCount(2, $json['advisories']['vendor1/package1']);
+
+        // Check first advisory
+        self::assertSame('CVE-2023-12345', $json['advisories']['vendor1/package1'][0]['cve']);
+        self::assertSame('First repo advisory', $json['advisories']['vendor1/package1'][0]['title']);
+
+        // Check second advisory
+        self::assertSame('CVE-2023-67890', $json['advisories']['vendor1/package1'][1]['cve']);
+        self::assertSame('Third repo advisory', $json['advisories']['vendor1/package1'][1]['title']);
+    }
+
     /**
      * @dataProvider ignoreSeverityProvider
-     * @phpstan-param array<\Composer\Package\Package> $packages
+     * @phpstan-param array<Package> $packages
      * @phpstan-param array<string> $ignoredSeverities
      * @phpstan-param 0|positive-int $exitCode
      * @phpstan-param list<array{text: string, verbosity?: \Composer\IO\IOInterface::*, regex?: true}|array{ask: string, reply: string}|array{auth: array{string, string, string|null}}> $expectedOutput
@@ -633,4 +834,56 @@ Found 2 abandoned packages:
 
         return $advisories;
     }
+
+    /**
+     * @dataProvider needsCompleteLoadProvider
+     * @param array<string, array<SecurityAdvisory|PartialSecurityAdvisory>> $advisories
+     * @param array<string> $ignoreList
+     */
+    public function testNeedsCompleteAdvisoryLoad(array $advisories, array $ignoreList, bool $expected): void
+    {
+        $auditor = new Auditor();
+        self::assertSame($expected, $auditor->needsCompleteAdvisoryLoad($advisories, $ignoreList));
+    }
+
+    /**
+     * @return array<array{array<string, array<SecurityAdvisory|PartialSecurityAdvisory>>, array<string>, bool}>
+     */
+    public static function needsCompleteLoadProvider(): array
+    {
+        return [
+            'no filter or advisories' => [[], [], false],
+            'packagist filters are IDs so work fine with partial advisories' => [[], ['PKSA-foo-bar'], false],
+            'packagist filters are IDs so work fine with partial advisories/2' => [
+                ['vendor1/package1' => [
+                    new SecurityAdvisory('foo/bar', '123', new Constraint('=', '1.0.0.0'), 'test', [['name' => 'foo', 'remoteId' => 'remoteID']], new DateTimeImmutable()),
+                    new PartialSecurityAdvisory('foo/bar', '1234', new Constraint('=', '1.0.0.0')),
+                ]],
+                ['PKSA-foo-bar'],
+                false
+            ],
+            'no advisories no need to load any further' => [[], ['CVE-2025-1234'], false],
+            'no advisories no need to load any further/2' => [['vendor1/package1' => []], ['CVE-2025-1234'], false],
+            'CVE filter or other non-packagist ones might need to fully load for safety if partial advisories are present' => [
+                ['vendor1/package1' => [
+                    new SecurityAdvisory('foo/bar', '123', new Constraint('=', '1.0.0.0'), 'test', [['name' => 'foo', 'remoteId' => 'remoteID']], new DateTimeImmutable()),
+                    new PartialSecurityAdvisory('foo/bar', '1234', new Constraint('=', '1.0.0.0')),
+                ]],
+                ['CVE-2025-1234'],
+                true,
+            ],
+            'filter does not trigger load if all advisories are fully loaded' => [
+                [
+                    'vendor1/package1' => [
+                        new SecurityAdvisory('foo/bar', '123', new Constraint('=', '1.0.0.0'), 'test', [['name' => 'foo', 'remoteId' => 'remoteID']], new DateTimeImmutable()),
+                    ],
+                    'vendor1/package2' => [
+                        new SecurityAdvisory('foo/bar', '1234', new Constraint('=', '1.0.0.0'), 'test', [['name' => 'foo', 'remoteId' => 'remoteID']], new DateTimeImmutable()),
+                    ]
+                ],
+                ['CVE-2025-1234'],
+                false,
+            ],
+        ];
+    }
 }
