@@ -23,8 +23,8 @@ class PoolTest extends TestCase
 
         $pool = $this->createPool([$package]);
 
-        $this->assertEquals([$package], $pool->whatProvides('foo'));
-        $this->assertEquals([$package], $pool->whatProvides('foo'));
+        self::assertEquals([$package], $pool->whatProvides('foo'));
+        self::assertEquals([$package], $pool->whatProvides('foo'));
     }
 
     public function testWhatProvidesPackageWithConstraint(): void
@@ -37,8 +37,8 @@ class PoolTest extends TestCase
             $secondPackage,
         ]);
 
-        $this->assertEquals([$firstPackage, $secondPackage], $pool->whatProvides('foo'));
-        $this->assertEquals([$secondPackage], $pool->whatProvides('foo', self::getVersionConstraint('==', '2')));
+        self::assertEquals([$firstPackage, $secondPackage], $pool->whatProvides('foo'));
+        self::assertEquals([$secondPackage], $pool->whatProvides('foo', self::getVersionConstraint('==', '2')));
     }
 
     public function testPackageById(): void
@@ -47,14 +47,14 @@ class PoolTest extends TestCase
 
         $pool = $this->createPool([$package]);
 
-        $this->assertSame($package, $pool->packageById(1));
+        self::assertSame($package, $pool->packageById(1));
     }
 
     public function testWhatProvidesWhenPackageCannotBeFound(): void
     {
         $pool = $this->createPool();
 
-        $this->assertEquals([], $pool->whatProvides('foo'));
+        self::assertEquals([], $pool->whatProvides('foo'));
     }
 
     /**
