@@ -387,6 +387,88 @@ class JsonFileTest extends TestCase
         unlink(__DIR__.'/Fixtures/tabs2.json');
     }
 
+    public function testComposerLockFileMergeConflictSimple(): void
+    {
+        $data = [
+            '_readme' => [
+                'This file locks the dependencies of your project to a known state',
+                'Read more about it at https://getcomposer.org/doc/01-basic-usage.md#installing-dependencies',
+                'This file is @generated automatically',
+            ],
+            'content-hash' => 'VCS merge conflict detected. Please run `composer update --lock`.',
+            'packages' => [],
+            'packages-dev' => [],
+            'aliases' => [],
+            'minimum-stability' => "stable",
+            'stability-flags' => [],
+            'prefer-stable' => false,
+            'prefer-lowest' => false,
+            'platform' => [],
+            'platform-dev' => [],
+            'plugin-api-version' => '2.3.0',
+        ];
+
+        $json = (string) file_get_contents(__DIR__ . '/Fixtures/composer-lock-merge-conflict-simple.txt');
+
+        $this->assertEquals($data, JsonFile::parseJson($json, '/path/to/composer.lock'));
+    }
+
+    public function testComposerLockFileMergeConflictSimpleCRLF(): void
+    {
+        $data = [
+            '_readme' => [
+                'This file locks the dependencies of your project to a known state',
+                'Read more about it at https://getcomposer.org/doc/01-basic-usage.md#installing-dependencies',
+                'This file is @generated automatically',
+            ],
+            'content-hash' => 'VCS merge conflict detected. Please run `composer update --lock`.',
+            'packages' => [],
+            'packages-dev' => [],
+            'aliases' => [],
+            'minimum-stability' => "stable",
+            'stability-flags' => [],
+            'prefer-stable' => false,
+            'prefer-lowest' => false,
+            'platform' => [],
+            'platform-dev' => [],
+            'plugin-api-version' => '2.3.0',
+        ];
+
+        $json = (string) file_get_contents(__DIR__ . '/Fixtures/composer-lock-merge-conflict-simple.txt');
+
+        $this->assertEquals($data, JsonFile::parseJson($json, '/path/to/composer.lock'));
+    }
+
+    public function testComposerLockFileMergeConflictComplex(): void
+    {
+        // complex files have multiple conflict markers and can thus not be simply resolved
+        $data = (string) file_get_contents(__DIR__ . '/Fixtures/composer-lock-merge-conflict-complex.txt');
+
+        $this->expectException(ParsingException::class);
+        // We don't care here what the error message says, just that there is an exception thrown.
+        // Other tests verify that the message text is sensible.
+        JsonFile::parseJson($data, '/path/to/composer.lock');
+    }
+
+    public function testComposerLockFileMergeConflictComplexCRLF(): void
+    {
+        // complex files have multiple conflict markers and can thus not be simply resolved
+        $data = (string) file_get_contents(__DIR__ . '/Fixtures/composer-lock-merge-conflict-complex-crlf.txt');
+
+        $this->expectException(ParsingException::class);
+        // We don't care here what the error message says, just that there is an exception thrown.
+        // Other tests verify that the message text is sensible.
+        JsonFile::parseJson($data, '/path/to/composer.lock');
+    }
+
+    public function testComposerLockFileMergeConflictExtended(): void
+    {
+        $data = (string) file_get_contents(__DIR__ . '/Fixtures/composer-lock-merge-conflict-extended.txt');
+
+        $json = JsonFile::parseJson($data, '/path/to/composer.lock');
+        self::assertSame('VCS merge conflict detected. Please run `composer update --lock`.', $json['content-hash']);
+    }
+
     private function expectParseException(string $text, string $json): void
     {
         try {
