@@ -90,7 +90,7 @@ class HttpDownloaderMock extends HttpDownloader
         }
 
         // dummy assertion to ensure the test is not marked as having no assertions
-        Assert::assertTrue(true); // @phpstan-ignore-line
+        Assert::assertTrue(true); // @phpstan-ignore staticMethod.alreadyNarrowedType
     }
 
     public function get($fileUrl, $options = []): Response
